<?php

namespace Drupal\shortcode_order\Plugin\Shortcode;

use Drupal\Core\Language\Language;
use Drupal\shortcode\Plugin\ShortcodeBase;

/**
 * Replace the given text formatted like as a Order block.
 *
 * @Shortcode(
 *   id = "order",
 *   title = @Translation("Order"),
 *   description = @Translation("Replace the given text formatted like as a Order block.")
 * )
 */
class OrderShortcode extends ShortcodeBase {

  /**
   * {@inheritdoc}
   */
  public function process(array $attributes, $text, $langcode = Language::LANGCODE_NOT_SPECIFIED) {

    // Merge with default attributes.
    $attributes = $this->getAttributes([
      'title' => 'Свяжитесь с нами',
      'label' => 'Заказать звонок',
    ],
      $attributes
    );

    if ($text === NULL || $text == '') {
      $text = 'Оставьте заявку на обратный звонок,  наши сотрудники свяжутся с вами в ближайшее время и ответят на все интересующие вопросы.';
    }

    $output = [
      '#theme' => 'shortcode_order',
      '#title' => $attributes['title'],
      '#label' => $attributes['label'],
      '#text' => $text,
    ];
    return $this->render($output);
  }

  /**
   * {@inheritdoc}
   */
  public function tips($long = FALSE) {
    $output = [];
    $output[] = '<p><strong>' . $this->t('[order][/order] or [order title="Custom title" label="Custom label"]Custom text[/order] for customization block') . '</strong>';
    if ($long) {
      $output[] = $this->t('Formats the text like as a order block.') . '</p>';
    }
    else {
      $output[] = $this->t('Formats the text like as a order block.') . '</p>';
    }

    return implode(' ', $output);
  }

}
